# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core/metric/v1beta/metric.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63ore/metric/v1beta/metric.proto\x12\x12\x63ore.metric.v1beta\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xec\x01\n\x1cReportPipelineTriggerRequest\x12\x36\n\x04user\x18\x01 \x01(\x0b\x32\x1c.core.metric.v1beta.UserDataB\x04\xe2\x41\x01\x02R\x04user\x12\x42\n\x08pipeline\x18\x02 \x01(\x0b\x32 .core.metric.v1beta.PipelineDataB\x04\xe2\x41\x01\x02R\x08pipeline\x12P\n\x0cusage_record\x18\x03 \x01(\x0b\x32\'.core.metric.v1beta.PipelineUsageRecordB\x04\xe2\x41\x01\x02R\x0busageRecord\"Z\n\x1dReportPipelineTriggerResponse\x12\x39\n\x04null\x18\x01 \x01(\x0b\x32\x1f.core.metric.v1beta.NullMessageB\x04\xe2\x41\x01\x01R\x04null\"\x91\x01\n\x1dReportPipelineTriggersRequest\x12p\n\x18pipeline_trigger_records\x18\x01 \x03(\x0b\x32\x30.core.metric.v1beta.ReportPipelineTriggerRequestB\x04\xe2\x41\x01\x02R\x16pipelineTriggerRecords\"[\n\x1eReportPipelineTriggersResponse\x12\x39\n\x04null\x18\x01 \x01(\x0b\x32\x1f.core.metric.v1beta.NullMessageB\x04\xe2\x41\x01\x01R\x04null\"\xe3\x01\n\x18ReportModelOnlineRequest\x12\x36\n\x04user\x18\x01 \x01(\x0b\x32\x1c.core.metric.v1beta.UserDataB\x04\xe2\x41\x01\x02R\x04user\x12\x39\n\x05model\x18\x02 \x01(\x0b\x32\x1d.core.metric.v1beta.ModelDataB\x04\xe2\x41\x01\x02R\x05model\x12T\n\x10\x63um_usage_record\x18\x03 \x01(\x0b\x32$.core.metric.v1beta.ModelUsageRecordB\x04\xe2\x41\x01\x02R\x0e\x63umUsageRecord\"V\n\x19ReportModelOnlineResponse\x12\x39\n\x04null\x18\x01 \x01(\x0b\x32\x1f.core.metric.v1beta.NullMessageB\x04\xe2\x41\x01\x01R\x04null\"\x81\x01\n\x19ReportModelOnlinesRequest\x12\x64\n\x14model_online_records\x18\x01 \x03(\x0b\x32,.core.metric.v1beta.ReportModelOnlineRequestB\x04\xe2\x41\x01\x02R\x12modelOnlineRecords\"W\n\x1aReportModelOnlinesResponse\x12\x39\n\x04null\x18\x01 \x01(\x0b\x32\x1f.core.metric.v1beta.NullMessageB\x04\xe2\x41\x01\x01R\x04null\"\x9a\x01\n\x13GetPipelinesRequest\x12\x36\n\x04user\x18\x01 \x01(\x0b\x32\x1c.core.metric.v1beta.UserDataB\x04\xe2\x41\x01\x02R\x04user\x12K\n\rtime_interval\x18\x02 \x01(\x0b\x32 .core.metric.v1beta.TimeIntervalB\x04\xe2\x41\x01\x02R\x0ctimeInterval\"\\\n\x14GetPipelinesResponse\x12\x44\n\tpipelines\x18\x01 \x03(\x0b\x32 .core.metric.v1beta.PipelineDataB\x04\xe2\x41\x01\x02R\tpipelines\"\x97\x01\n\x10GetModelsRequest\x12\x36\n\x04user\x18\x01 \x01(\x0b\x32\x1c.core.metric.v1beta.UserDataB\x04\xe2\x41\x01\x02R\x04user\x12K\n\rtime_interval\x18\x02 \x01(\x0b\x32 .core.metric.v1beta.TimeIntervalB\x04\xe2\x41\x01\x02R\x0ctimeInterval\"P\n\x11GetModelsResponse\x12;\n\x06models\x18\x01 \x03(\x0b\x32\x1d.core.metric.v1beta.ModelDataB\x04\xe2\x41\x01\x02R\x06models\"\xeb\x01\n GetPipelineTriggerRecordsRequest\x12\x36\n\x04user\x18\x01 \x01(\x0b\x32\x1c.core.metric.v1beta.UserDataB\x04\xe2\x41\x01\x02R\x04user\x12\x42\n\x08pipeline\x18\x02 \x01(\x0b\x32 .core.metric.v1beta.PipelineDataB\x04\xe2\x41\x01\x02R\x08pipeline\x12K\n\rtime_interval\x18\x03 \x01(\x0b\x32 .core.metric.v1beta.TimeIntervalB\x04\xe2\x41\x01\x01R\x0ctimeInterval\"l\n!GetPipelineTriggerRecordsResponse\x12G\n\x07records\x18\x01 \x03(\x0b\x32\'.core.metric.v1beta.PipelineUsageRecordB\x04\xe2\x41\x01\x02R\x07records\"\x85\x01\n$GetBulkPipelineTriggerRecordsRequest\x12]\n\x0c\x62ulk_queries\x18\x01 \x03(\x0b\x32\x34.core.metric.v1beta.GetPipelineTriggerRecordsRequestB\x04\xe2\x41\x01\x02R\x0b\x62ulkQueries\"\x87\x01\n%GetBulkPipelineTriggerRecordsResponse\x12^\n\x0c\x62ulk_records\x18\x01 \x03(\x0b\x32\x35.core.metric.v1beta.GetPipelineTriggerRecordsResponseB\x04\xe2\x41\x01\x02R\x0b\x62ulkRecords\"\xf5\x01\n*GetCumulativePipelineTriggerRecordsRequest\x12\x36\n\x04user\x18\x01 \x01(\x0b\x32\x1c.core.metric.v1beta.UserDataB\x04\xe2\x41\x01\x02R\x04user\x12\x42\n\x08pipeline\x18\x02 \x01(\x0b\x32 .core.metric.v1beta.PipelineDataB\x04\xe2\x41\x01\x02R\x08pipeline\x12K\n\rtime_interval\x18\x03 \x01(\x0b\x32 .core.metric.v1beta.TimeIntervalB\x04\xe2\x41\x01\x01R\x0ctimeInterval\"\x8b\x01\n+GetCumulativePipelineTriggerRecordsResponse\x12\\\n\x12\x63umulative_records\x18\x01 \x03(\x0b\x32\'.core.metric.v1beta.PipelineUsageRecordB\x04\xe2\x41\x01\x02R\x11\x63umulativeRecords\"\x99\x01\n.GetBulkCumulativePipelineTriggerRecordsRequest\x12g\n\x0c\x62ulk_queries\x18\x01 \x03(\x0b\x32>.core.metric.v1beta.GetCumulativePipelineTriggerRecordsRequestB\x04\xe2\x41\x01\x02R\x0b\x62ulkQueries\"\xb0\x01\n/GetBulkCumulativePipelineTriggerRecordsResponse\x12}\n\x17\x62ulk_cumulative_records\x18\x01 \x03(\x0b\x32?.core.metric.v1beta.GetCumulativePipelineTriggerRecordsResponseB\x04\xe2\x41\x01\x02R\x15\x62ulkCumulativeRecords\"\xeb\x01\n GetPipelineTriggerSummaryRequest\x12\x36\n\x04user\x18\x01 \x01(\x0b\x32\x1c.core.metric.v1beta.UserDataB\x04\xe2\x41\x01\x02R\x04user\x12\x42\n\x08pipeline\x18\x02 \x01(\x0b\x32 .core.metric.v1beta.PipelineDataB\x04\xe2\x41\x01\x02R\x08pipeline\x12K\n\rtime_interval\x18\x03 \x01(\x0b\x32 .core.metric.v1beta.TimeIntervalB\x04\xe2\x41\x01\x01R\x0ctimeInterval\"i\n!GetPipelineTriggerSummaryResponse\x12\x44\n\tsummaries\x18\x01 \x01(\x0b\x32 .core.metric.v1beta.UsageSummaryB\x04\xe2\x41\x01\x02R\tsummaries\"\x87\x01\n&GetBulkPipelineTriggerSummariesRequest\x12]\n\x0c\x62ulk_queries\x18\x01 \x03(\x0b\x32\x34.core.metric.v1beta.GetPipelineTriggerSummaryRequestB\x04\xe2\x41\x01\x02R\x0b\x62ulkQueries\"\x8d\x01\n\'GetBulkPipelineTriggerSummariesResponse\x12\x62\n\x0e\x62ulk_summaries\x18\x01 \x03(\x0b\x32\x35.core.metric.v1beta.GetPipelineTriggerSummaryResponseB\x04\xe2\x41\x01\x02R\rbulkSummaries\"\xde\x01\n\x1cGetModelOnlineRecordsRequest\x12\x36\n\x04user\x18\x01 \x01(\x0b\x32\x1c.core.metric.v1beta.UserDataB\x04\xe2\x41\x01\x02R\x04user\x12\x39\n\x05model\x18\x02 \x01(\x0b\x32\x1d.core.metric.v1beta.ModelDataB\x04\xe2\x41\x01\x02R\x05model\x12K\n\rtime_interval\x18\x03 \x01(\x0b\x32 .core.metric.v1beta.TimeIntervalB\x04\xe2\x41\x01\x02R\x0ctimeInterval\"e\n\x1dGetModelOnlineRecordsResponse\x12\x44\n\x07records\x18\x01 \x03(\x0b\x32$.core.metric.v1beta.ModelUsageRecordB\x04\xe2\x41\x01\x02R\x07records\"}\n GetBulkModelOnlineRecordsRequest\x12Y\n\x0c\x62ulk_queries\x18\x01 \x03(\x0b\x32\x30.core.metric.v1beta.GetModelOnlineRecordsRequestB\x04\xe2\x41\x01\x02R\x0b\x62ulkQueries\"\x7f\n!GetBulkModelOnlineRecordsResponse\x12Z\n\x0c\x62ulk_records\x18\x01 \x03(\x0b\x32\x31.core.metric.v1beta.GetModelOnlineRecordsResponseB\x04\xe2\x41\x01\x02R\x0b\x62ulkRecords\"\xe8\x01\n&GetCumulativeModelOnlineRecordsRequest\x12\x36\n\x04user\x18\x01 \x01(\x0b\x32\x1c.core.metric.v1beta.UserDataB\x04\xe2\x41\x01\x02R\x04user\x12\x39\n\x05model\x18\x02 \x01(\x0b\x32\x1d.core.metric.v1beta.ModelDataB\x04\xe2\x41\x01\x02R\x05model\x12K\n\rtime_interval\x18\x03 \x01(\x0b\x32 .core.metric.v1beta.TimeIntervalB\x04\xe2\x41\x01\x02R\x0ctimeInterval\"\x84\x01\n\'GetCumulativeModelOnlineRecordsResponse\x12Y\n\x12\x63umulative_records\x18\x01 \x03(\x0b\x32$.core.metric.v1beta.ModelUsageRecordB\x04\xe2\x41\x01\x02R\x11\x63umulativeRecords\"\x91\x01\n*GetBulkCumulativeModelOnlineRecordsRequest\x12\x63\n\x0c\x62ulk_queries\x18\x01 \x03(\x0b\x32:.core.metric.v1beta.GetCumulativeModelOnlineRecordsRequestB\x04\xe2\x41\x01\x02R\x0b\x62ulkQueries\"\xa8\x01\n+GetBulkCumulativeModelOnlineRecordsResponse\x12y\n\x17\x62ulk_cumulative_records\x18\x01 \x03(\x0b\x32;.core.metric.v1beta.GetCumulativeModelOnlineRecordsResponseB\x04\xe2\x41\x01\x02R\x15\x62ulkCumulativeRecords\"\xde\x01\n\x1cGetModelOnlineSummaryRequest\x12\x36\n\x04user\x18\x01 \x01(\x0b\x32\x1c.core.metric.v1beta.UserDataB\x04\xe2\x41\x01\x02R\x04user\x12\x39\n\x05model\x18\x02 \x01(\x0b\x32\x1d.core.metric.v1beta.ModelDataB\x04\xe2\x41\x01\x02R\x05model\x12K\n\rtime_interval\x18\x03 \x01(\x0b\x32 .core.metric.v1beta.TimeIntervalB\x04\xe2\x41\x01\x02R\x0ctimeInterval\"a\n\x1dGetModelOnlineSummaryResponse\x12@\n\x07summary\x18\x01 \x01(\x0b\x32 .core.metric.v1beta.UsageSummaryB\x04\xe2\x41\x01\x02R\x07summary\"}\n GetBulkModelOnlineSummaryRequest\x12Y\n\x0c\x62ulk_queries\x18\x01 \x03(\x0b\x32\x30.core.metric.v1beta.GetModelOnlineSummaryRequestB\x04\xe2\x41\x01\x02R\x0b\x62ulkQueries\"\x83\x01\n!GetBulkModelOnlineSummaryResponse\x12^\n\x0e\x62ulk_summaries\x18\x01 \x03(\x0b\x32\x31.core.metric.v1beta.GetModelOnlineSummaryResponseB\x04\xe2\x41\x01\x02R\rbulkSummaries\"\xe9\x01\n\x1eGetPipelineTriggerPriceRequest\x12\x36\n\x04user\x18\x01 \x01(\x0b\x32\x1c.core.metric.v1beta.UserDataB\x04\xe2\x41\x01\x02R\x04user\x12\x42\n\x08pipeline\x18\x02 \x01(\x0b\x32 .core.metric.v1beta.PipelineDataB\x04\xe2\x41\x01\x02R\x08pipeline\x12K\n\rtime_interval\x18\x03 \x01(\x0b\x32 .core.metric.v1beta.TimeIntervalB\x04\xe2\x41\x01\x02R\x0ctimeInterval\"\\\n\x1fGetPipelineTriggerPriceResponse\x12\x39\n\x05price\x18\x01 \x03(\x0b\x32\x1d.core.metric.v1beta.PriceDataB\x04\xe2\x41\x01\x02R\x05price\"\x81\x01\n\"GetBulkPipelineTriggerPriceRequest\x12[\n\x0c\x62ulk_queries\x18\x01 \x03(\x0b\x32\x32.core.metric.v1beta.GetPipelineTriggerPriceRequestB\x04\xe2\x41\x01\x02R\x0b\x62ulkQueries\"\x81\x01\n#GetBulkPipelineTriggerPriceResponse\x12Z\n\x0b\x62ulk_prices\x18\x01 \x03(\x0b\x32\x33.core.metric.v1beta.GetPipelineTriggerPriceResponseB\x04\xe2\x41\x01\x02R\nbulkPrices\"\xdc\x01\n\x1aGetModelOnlinePriceRequest\x12\x36\n\x04user\x18\x01 \x01(\x0b\x32\x1c.core.metric.v1beta.UserDataB\x04\xe2\x41\x01\x02R\x04user\x12\x39\n\x05model\x18\x02 \x01(\x0b\x32\x1d.core.metric.v1beta.ModelDataB\x04\xe2\x41\x01\x02R\x05model\x12K\n\rtime_interval\x18\x03 \x01(\x0b\x32 .core.metric.v1beta.TimeIntervalB\x04\xe2\x41\x01\x02R\x0ctimeInterval\"X\n\x1bGetModelOnlinePriceResponse\x12\x39\n\x05price\x18\x01 \x03(\x0b\x32\x1d.core.metric.v1beta.PriceDataB\x04\xe2\x41\x01\x02R\x05price\"y\n\x1eGetBulkModelOnlinePriceRequest\x12W\n\x0c\x62ulk_queries\x18\x01 \x03(\x0b\x32..core.metric.v1beta.GetModelOnlinePriceRequestB\x04\xe2\x41\x01\x02R\x0b\x62ulkQueries\"y\n\x1fGetBulkModelOnlinePriceResponse\x12V\n\x0b\x62ulk_prices\x18\x01 \x03(\x0b\x32/.core.metric.v1beta.GetModelOnlinePriceResponseB\x04\xe2\x41\x01\x02R\nbulkPrices\"\r\n\x0bNullMessage\"<\n\x08UserData\x12\x16\n\x03uid\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x03uid\x12\x18\n\x04name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x04name\"V\n\x0cPipelineData\x12\x16\n\x03uid\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x03uid\x12\x14\n\x02id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x02id\x12\x18\n\x04task\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x04task\"\xa5\x02\n\x13PipelineUsageRecord\x12#\n\nrequest_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\trequestId\x12\'\n\x0coperation_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x0boperationId\x12\x1c\n\x06status\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x06status\x12\x43\n\x0ctrigger_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x02R\x0btriggerTime\x12\x41\n\x0brecord_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x02R\nrecordTime\x12\x1a\n\x05value\x18\x06 \x01(\x05\x42\x04\xe2\x41\x01\x02R\x05value\"z\n\tModelData\x12\x16\n\x03uid\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x03uid\x12\x14\n\x02id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x02id\x12%\n\x0binstance_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\ninstanceId\x12\x18\n\x04task\x18\x04 \x01(\tB\x04\xe2\x41\x01\x02R\x04task\"\xb4\x01\n\x10ModelUsageRecord\x12\x41\n\x0b\x64\x65ploy_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x02R\ndeployTime\x12\x41\n\x0brecord_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x02R\nrecordTime\x12\x1a\n\x05value\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x02R\x05value\"`\n\x0cUsageSummary\x12\x34\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x02R\x04time\x12\x1a\n\x05value\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x02R\x05value\"\x87\x01\n\tPriceData\x12:\n\x04time\x18\x01 \x01(\x0b\x32 .core.metric.v1beta.TimeIntervalB\x04\xe2\x41\x01\x02R\x04time\x12 \n\x08\x63urrency\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03R\x08\x63urrency\x12\x1c\n\x06\x61mount\x18\x03 \x01(\x02\x42\x04\xe2\x41\x01\x03R\x06\x61mount\"\x8c\x01\n\x0cTimeInterval\x12?\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x02R\tstartTime\x12;\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x02R\x07\x65ndTimeB\xd2\x01\n\x16\x63om.core.metric.v1betaB\x0bMetricProtoP\x01ZAgithub.com/instill-ai/protogen-go/core/metric/v1beta;metricv1beta\xa2\x02\x03\x43MX\xaa\x02\x12\x43ore.Metric.V1beta\xca\x02\x12\x43ore\\Metric\\V1beta\xe2\x02\x1e\x43ore\\Metric\\V1beta\\GPBMetadata\xea\x02\x14\x43ore::Metric::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core.metric.v1beta.metric_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.core.metric.v1betaB\013MetricProtoP\001ZAgithub.com/instill-ai/protogen-go/core/metric/v1beta;metricv1beta\242\002\003CMX\252\002\022Core.Metric.V1beta\312\002\022Core\\Metric\\V1beta\342\002\036Core\\Metric\\V1beta\\GPBMetadata\352\002\024Core::Metric::V1beta'
  _REPORTPIPELINETRIGGERREQUEST.fields_by_name['user']._options = None
  _REPORTPIPELINETRIGGERREQUEST.fields_by_name['user']._serialized_options = b'\342A\001\002'
  _REPORTPIPELINETRIGGERREQUEST.fields_by_name['pipeline']._options = None
  _REPORTPIPELINETRIGGERREQUEST.fields_by_name['pipeline']._serialized_options = b'\342A\001\002'
  _REPORTPIPELINETRIGGERREQUEST.fields_by_name['usage_record']._options = None
  _REPORTPIPELINETRIGGERREQUEST.fields_by_name['usage_record']._serialized_options = b'\342A\001\002'
  _REPORTPIPELINETRIGGERRESPONSE.fields_by_name['null']._options = None
  _REPORTPIPELINETRIGGERRESPONSE.fields_by_name['null']._serialized_options = b'\342A\001\001'
  _REPORTPIPELINETRIGGERSREQUEST.fields_by_name['pipeline_trigger_records']._options = None
  _REPORTPIPELINETRIGGERSREQUEST.fields_by_name['pipeline_trigger_records']._serialized_options = b'\342A\001\002'
  _REPORTPIPELINETRIGGERSRESPONSE.fields_by_name['null']._options = None
  _REPORTPIPELINETRIGGERSRESPONSE.fields_by_name['null']._serialized_options = b'\342A\001\001'
  _REPORTMODELONLINEREQUEST.fields_by_name['user']._options = None
  _REPORTMODELONLINEREQUEST.fields_by_name['user']._serialized_options = b'\342A\001\002'
  _REPORTMODELONLINEREQUEST.fields_by_name['model']._options = None
  _REPORTMODELONLINEREQUEST.fields_by_name['model']._serialized_options = b'\342A\001\002'
  _REPORTMODELONLINEREQUEST.fields_by_name['cum_usage_record']._options = None
  _REPORTMODELONLINEREQUEST.fields_by_name['cum_usage_record']._serialized_options = b'\342A\001\002'
  _REPORTMODELONLINERESPONSE.fields_by_name['null']._options = None
  _REPORTMODELONLINERESPONSE.fields_by_name['null']._serialized_options = b'\342A\001\001'
  _REPORTMODELONLINESREQUEST.fields_by_name['model_online_records']._options = None
  _REPORTMODELONLINESREQUEST.fields_by_name['model_online_records']._serialized_options = b'\342A\001\002'
  _REPORTMODELONLINESRESPONSE.fields_by_name['null']._options = None
  _REPORTMODELONLINESRESPONSE.fields_by_name['null']._serialized_options = b'\342A\001\001'
  _GETPIPELINESREQUEST.fields_by_name['user']._options = None
  _GETPIPELINESREQUEST.fields_by_name['user']._serialized_options = b'\342A\001\002'
  _GETPIPELINESREQUEST.fields_by_name['time_interval']._options = None
  _GETPIPELINESREQUEST.fields_by_name['time_interval']._serialized_options = b'\342A\001\002'
  _GETPIPELINESRESPONSE.fields_by_name['pipelines']._options = None
  _GETPIPELINESRESPONSE.fields_by_name['pipelines']._serialized_options = b'\342A\001\002'
  _GETMODELSREQUEST.fields_by_name['user']._options = None
  _GETMODELSREQUEST.fields_by_name['user']._serialized_options = b'\342A\001\002'
  _GETMODELSREQUEST.fields_by_name['time_interval']._options = None
  _GETMODELSREQUEST.fields_by_name['time_interval']._serialized_options = b'\342A\001\002'
  _GETMODELSRESPONSE.fields_by_name['models']._options = None
  _GETMODELSRESPONSE.fields_by_name['models']._serialized_options = b'\342A\001\002'
  _GETPIPELINETRIGGERRECORDSREQUEST.fields_by_name['user']._options = None
  _GETPIPELINETRIGGERRECORDSREQUEST.fields_by_name['user']._serialized_options = b'\342A\001\002'
  _GETPIPELINETRIGGERRECORDSREQUEST.fields_by_name['pipeline']._options = None
  _GETPIPELINETRIGGERRECORDSREQUEST.fields_by_name['pipeline']._serialized_options = b'\342A\001\002'
  _GETPIPELINETRIGGERRECORDSREQUEST.fields_by_name['time_interval']._options = None
  _GETPIPELINETRIGGERRECORDSREQUEST.fields_by_name['time_interval']._serialized_options = b'\342A\001\001'
  _GETPIPELINETRIGGERRECORDSRESPONSE.fields_by_name['records']._options = None
  _GETPIPELINETRIGGERRECORDSRESPONSE.fields_by_name['records']._serialized_options = b'\342A\001\002'
  _GETBULKPIPELINETRIGGERRECORDSREQUEST.fields_by_name['bulk_queries']._options = None
  _GETBULKPIPELINETRIGGERRECORDSREQUEST.fields_by_name['bulk_queries']._serialized_options = b'\342A\001\002'
  _GETBULKPIPELINETRIGGERRECORDSRESPONSE.fields_by_name['bulk_records']._options = None
  _GETBULKPIPELINETRIGGERRECORDSRESPONSE.fields_by_name['bulk_records']._serialized_options = b'\342A\001\002'
  _GETCUMULATIVEPIPELINETRIGGERRECORDSREQUEST.fields_by_name['user']._options = None
  _GETCUMULATIVEPIPELINETRIGGERRECORDSREQUEST.fields_by_name['user']._serialized_options = b'\342A\001\002'
  _GETCUMULATIVEPIPELINETRIGGERRECORDSREQUEST.fields_by_name['pipeline']._options = None
  _GETCUMULATIVEPIPELINETRIGGERRECORDSREQUEST.fields_by_name['pipeline']._serialized_options = b'\342A\001\002'
  _GETCUMULATIVEPIPELINETRIGGERRECORDSREQUEST.fields_by_name['time_interval']._options = None
  _GETCUMULATIVEPIPELINETRIGGERRECORDSREQUEST.fields_by_name['time_interval']._serialized_options = b'\342A\001\001'
  _GETCUMULATIVEPIPELINETRIGGERRECORDSRESPONSE.fields_by_name['cumulative_records']._options = None
  _GETCUMULATIVEPIPELINETRIGGERRECORDSRESPONSE.fields_by_name['cumulative_records']._serialized_options = b'\342A\001\002'
  _GETBULKCUMULATIVEPIPELINETRIGGERRECORDSREQUEST.fields_by_name['bulk_queries']._options = None
  _GETBULKCUMULATIVEPIPELINETRIGGERRECORDSREQUEST.fields_by_name['bulk_queries']._serialized_options = b'\342A\001\002'
  _GETBULKCUMULATIVEPIPELINETRIGGERRECORDSRESPONSE.fields_by_name['bulk_cumulative_records']._options = None
  _GETBULKCUMULATIVEPIPELINETRIGGERRECORDSRESPONSE.fields_by_name['bulk_cumulative_records']._serialized_options = b'\342A\001\002'
  _GETPIPELINETRIGGERSUMMARYREQUEST.fields_by_name['user']._options = None
  _GETPIPELINETRIGGERSUMMARYREQUEST.fields_by_name['user']._serialized_options = b'\342A\001\002'
  _GETPIPELINETRIGGERSUMMARYREQUEST.fields_by_name['pipeline']._options = None
  _GETPIPELINETRIGGERSUMMARYREQUEST.fields_by_name['pipeline']._serialized_options = b'\342A\001\002'
  _GETPIPELINETRIGGERSUMMARYREQUEST.fields_by_name['time_interval']._options = None
  _GETPIPELINETRIGGERSUMMARYREQUEST.fields_by_name['time_interval']._serialized_options = b'\342A\001\001'
  _GETPIPELINETRIGGERSUMMARYRESPONSE.fields_by_name['summaries']._options = None
  _GETPIPELINETRIGGERSUMMARYRESPONSE.fields_by_name['summaries']._serialized_options = b'\342A\001\002'
  _GETBULKPIPELINETRIGGERSUMMARIESREQUEST.fields_by_name['bulk_queries']._options = None
  _GETBULKPIPELINETRIGGERSUMMARIESREQUEST.fields_by_name['bulk_queries']._serialized_options = b'\342A\001\002'
  _GETBULKPIPELINETRIGGERSUMMARIESRESPONSE.fields_by_name['bulk_summaries']._options = None
  _GETBULKPIPELINETRIGGERSUMMARIESRESPONSE.fields_by_name['bulk_summaries']._serialized_options = b'\342A\001\002'
  _GETMODELONLINERECORDSREQUEST.fields_by_name['user']._options = None
  _GETMODELONLINERECORDSREQUEST.fields_by_name['user']._serialized_options = b'\342A\001\002'
  _GETMODELONLINERECORDSREQUEST.fields_by_name['model']._options = None
  _GETMODELONLINERECORDSREQUEST.fields_by_name['model']._serialized_options = b'\342A\001\002'
  _GETMODELONLINERECORDSREQUEST.fields_by_name['time_interval']._options = None
  _GETMODELONLINERECORDSREQUEST.fields_by_name['time_interval']._serialized_options = b'\342A\001\002'
  _GETMODELONLINERECORDSRESPONSE.fields_by_name['records']._options = None
  _GETMODELONLINERECORDSRESPONSE.fields_by_name['records']._serialized_options = b'\342A\001\002'
  _GETBULKMODELONLINERECORDSREQUEST.fields_by_name['bulk_queries']._options = None
  _GETBULKMODELONLINERECORDSREQUEST.fields_by_name['bulk_queries']._serialized_options = b'\342A\001\002'
  _GETBULKMODELONLINERECORDSRESPONSE.fields_by_name['bulk_records']._options = None
  _GETBULKMODELONLINERECORDSRESPONSE.fields_by_name['bulk_records']._serialized_options = b'\342A\001\002'
  _GETCUMULATIVEMODELONLINERECORDSREQUEST.fields_by_name['user']._options = None
  _GETCUMULATIVEMODELONLINERECORDSREQUEST.fields_by_name['user']._serialized_options = b'\342A\001\002'
  _GETCUMULATIVEMODELONLINERECORDSREQUEST.fields_by_name['model']._options = None
  _GETCUMULATIVEMODELONLINERECORDSREQUEST.fields_by_name['model']._serialized_options = b'\342A\001\002'
  _GETCUMULATIVEMODELONLINERECORDSREQUEST.fields_by_name['time_interval']._options = None
  _GETCUMULATIVEMODELONLINERECORDSREQUEST.fields_by_name['time_interval']._serialized_options = b'\342A\001\002'
  _GETCUMULATIVEMODELONLINERECORDSRESPONSE.fields_by_name['cumulative_records']._options = None
  _GETCUMULATIVEMODELONLINERECORDSRESPONSE.fields_by_name['cumulative_records']._serialized_options = b'\342A\001\002'
  _GETBULKCUMULATIVEMODELONLINERECORDSREQUEST.fields_by_name['bulk_queries']._options = None
  _GETBULKCUMULATIVEMODELONLINERECORDSREQUEST.fields_by_name['bulk_queries']._serialized_options = b'\342A\001\002'
  _GETBULKCUMULATIVEMODELONLINERECORDSRESPONSE.fields_by_name['bulk_cumulative_records']._options = None
  _GETBULKCUMULATIVEMODELONLINERECORDSRESPONSE.fields_by_name['bulk_cumulative_records']._serialized_options = b'\342A\001\002'
  _GETMODELONLINESUMMARYREQUEST.fields_by_name['user']._options = None
  _GETMODELONLINESUMMARYREQUEST.fields_by_name['user']._serialized_options = b'\342A\001\002'
  _GETMODELONLINESUMMARYREQUEST.fields_by_name['model']._options = None
  _GETMODELONLINESUMMARYREQUEST.fields_by_name['model']._serialized_options = b'\342A\001\002'
  _GETMODELONLINESUMMARYREQUEST.fields_by_name['time_interval']._options = None
  _GETMODELONLINESUMMARYREQUEST.fields_by_name['time_interval']._serialized_options = b'\342A\001\002'
  _GETMODELONLINESUMMARYRESPONSE.fields_by_name['summary']._options = None
  _GETMODELONLINESUMMARYRESPONSE.fields_by_name['summary']._serialized_options = b'\342A\001\002'
  _GETBULKMODELONLINESUMMARYREQUEST.fields_by_name['bulk_queries']._options = None
  _GETBULKMODELONLINESUMMARYREQUEST.fields_by_name['bulk_queries']._serialized_options = b'\342A\001\002'
  _GETBULKMODELONLINESUMMARYRESPONSE.fields_by_name['bulk_summaries']._options = None
  _GETBULKMODELONLINESUMMARYRESPONSE.fields_by_name['bulk_summaries']._serialized_options = b'\342A\001\002'
  _GETPIPELINETRIGGERPRICEREQUEST.fields_by_name['user']._options = None
  _GETPIPELINETRIGGERPRICEREQUEST.fields_by_name['user']._serialized_options = b'\342A\001\002'
  _GETPIPELINETRIGGERPRICEREQUEST.fields_by_name['pipeline']._options = None
  _GETPIPELINETRIGGERPRICEREQUEST.fields_by_name['pipeline']._serialized_options = b'\342A\001\002'
  _GETPIPELINETRIGGERPRICEREQUEST.fields_by_name['time_interval']._options = None
  _GETPIPELINETRIGGERPRICEREQUEST.fields_by_name['time_interval']._serialized_options = b'\342A\001\002'
  _GETPIPELINETRIGGERPRICERESPONSE.fields_by_name['price']._options = None
  _GETPIPELINETRIGGERPRICERESPONSE.fields_by_name['price']._serialized_options = b'\342A\001\002'
  _GETBULKPIPELINETRIGGERPRICEREQUEST.fields_by_name['bulk_queries']._options = None
  _GETBULKPIPELINETRIGGERPRICEREQUEST.fields_by_name['bulk_queries']._serialized_options = b'\342A\001\002'
  _GETBULKPIPELINETRIGGERPRICERESPONSE.fields_by_name['bulk_prices']._options = None
  _GETBULKPIPELINETRIGGERPRICERESPONSE.fields_by_name['bulk_prices']._serialized_options = b'\342A\001\002'
  _GETMODELONLINEPRICEREQUEST.fields_by_name['user']._options = None
  _GETMODELONLINEPRICEREQUEST.fields_by_name['user']._serialized_options = b'\342A\001\002'
  _GETMODELONLINEPRICEREQUEST.fields_by_name['model']._options = None
  _GETMODELONLINEPRICEREQUEST.fields_by_name['model']._serialized_options = b'\342A\001\002'
  _GETMODELONLINEPRICEREQUEST.fields_by_name['time_interval']._options = None
  _GETMODELONLINEPRICEREQUEST.fields_by_name['time_interval']._serialized_options = b'\342A\001\002'
  _GETMODELONLINEPRICERESPONSE.fields_by_name['price']._options = None
  _GETMODELONLINEPRICERESPONSE.fields_by_name['price']._serialized_options = b'\342A\001\002'
  _GETBULKMODELONLINEPRICEREQUEST.fields_by_name['bulk_queries']._options = None
  _GETBULKMODELONLINEPRICEREQUEST.fields_by_name['bulk_queries']._serialized_options = b'\342A\001\002'
  _GETBULKMODELONLINEPRICERESPONSE.fields_by_name['bulk_prices']._options = None
  _GETBULKMODELONLINEPRICERESPONSE.fields_by_name['bulk_prices']._serialized_options = b'\342A\001\002'
  _USERDATA.fields_by_name['uid']._options = None
  _USERDATA.fields_by_name['uid']._serialized_options = b'\342A\001\002'
  _USERDATA.fields_by_name['name']._options = None
  _USERDATA.fields_by_name['name']._serialized_options = b'\342A\001\001'
  _PIPELINEDATA.fields_by_name['uid']._options = None
  _PIPELINEDATA.fields_by_name['uid']._serialized_options = b'\342A\001\002'
  _PIPELINEDATA.fields_by_name['id']._options = None
  _PIPELINEDATA.fields_by_name['id']._serialized_options = b'\342A\001\002'
  _PIPELINEDATA.fields_by_name['task']._options = None
  _PIPELINEDATA.fields_by_name['task']._serialized_options = b'\342A\001\002'
  _PIPELINEUSAGERECORD.fields_by_name['request_id']._options = None
  _PIPELINEUSAGERECORD.fields_by_name['request_id']._serialized_options = b'\342A\001\002'
  _PIPELINEUSAGERECORD.fields_by_name['operation_id']._options = None
  _PIPELINEUSAGERECORD.fields_by_name['operation_id']._serialized_options = b'\342A\001\002'
  _PIPELINEUSAGERECORD.fields_by_name['status']._options = None
  _PIPELINEUSAGERECORD.fields_by_name['status']._serialized_options = b'\342A\001\002'
  _PIPELINEUSAGERECORD.fields_by_name['trigger_time']._options = None
  _PIPELINEUSAGERECORD.fields_by_name['trigger_time']._serialized_options = b'\342A\001\002'
  _PIPELINEUSAGERECORD.fields_by_name['record_time']._options = None
  _PIPELINEUSAGERECORD.fields_by_name['record_time']._serialized_options = b'\342A\001\002'
  _PIPELINEUSAGERECORD.fields_by_name['value']._options = None
  _PIPELINEUSAGERECORD.fields_by_name['value']._serialized_options = b'\342A\001\002'
  _MODELDATA.fields_by_name['uid']._options = None
  _MODELDATA.fields_by_name['uid']._serialized_options = b'\342A\001\002'
  _MODELDATA.fields_by_name['id']._options = None
  _MODELDATA.fields_by_name['id']._serialized_options = b'\342A\001\002'
  _MODELDATA.fields_by_name['instance_id']._options = None
  _MODELDATA.fields_by_name['instance_id']._serialized_options = b'\342A\001\002'
  _MODELDATA.fields_by_name['task']._options = None
  _MODELDATA.fields_by_name['task']._serialized_options = b'\342A\001\002'
  _MODELUSAGERECORD.fields_by_name['deploy_time']._options = None
  _MODELUSAGERECORD.fields_by_name['deploy_time']._serialized_options = b'\342A\001\002'
  _MODELUSAGERECORD.fields_by_name['record_time']._options = None
  _MODELUSAGERECORD.fields_by_name['record_time']._serialized_options = b'\342A\001\002'
  _MODELUSAGERECORD.fields_by_name['value']._options = None
  _MODELUSAGERECORD.fields_by_name['value']._serialized_options = b'\342A\001\002'
  _USAGESUMMARY.fields_by_name['time']._options = None
  _USAGESUMMARY.fields_by_name['time']._serialized_options = b'\342A\001\002'
  _USAGESUMMARY.fields_by_name['value']._options = None
  _USAGESUMMARY.fields_by_name['value']._serialized_options = b'\342A\001\002'
  _PRICEDATA.fields_by_name['time']._options = None
  _PRICEDATA.fields_by_name['time']._serialized_options = b'\342A\001\002'
  _PRICEDATA.fields_by_name['currency']._options = None
  _PRICEDATA.fields_by_name['currency']._serialized_options = b'\342A\001\003'
  _PRICEDATA.fields_by_name['amount']._options = None
  _PRICEDATA.fields_by_name['amount']._serialized_options = b'\342A\001\003'
  _TIMEINTERVAL.fields_by_name['start_time']._options = None
  _TIMEINTERVAL.fields_by_name['start_time']._serialized_options = b'\342A\001\002'
  _TIMEINTERVAL.fields_by_name['end_time']._options = None
  _TIMEINTERVAL.fields_by_name['end_time']._serialized_options = b'\342A\001\002'
  _globals['_REPORTPIPELINETRIGGERREQUEST']._serialized_start=122
  _globals['_REPORTPIPELINETRIGGERREQUEST']._serialized_end=358
  _globals['_REPORTPIPELINETRIGGERRESPONSE']._serialized_start=360
  _globals['_REPORTPIPELINETRIGGERRESPONSE']._serialized_end=450
  _globals['_REPORTPIPELINETRIGGERSREQUEST']._serialized_start=453
  _globals['_REPORTPIPELINETRIGGERSREQUEST']._serialized_end=598
  _globals['_REPORTPIPELINETRIGGERSRESPONSE']._serialized_start=600
  _globals['_REPORTPIPELINETRIGGERSRESPONSE']._serialized_end=691
  _globals['_REPORTMODELONLINEREQUEST']._serialized_start=694
  _globals['_REPORTMODELONLINEREQUEST']._serialized_end=921
  _globals['_REPORTMODELONLINERESPONSE']._serialized_start=923
  _globals['_REPORTMODELONLINERESPONSE']._serialized_end=1009
  _globals['_REPORTMODELONLINESREQUEST']._serialized_start=1012
  _globals['_REPORTMODELONLINESREQUEST']._serialized_end=1141
  _globals['_REPORTMODELONLINESRESPONSE']._serialized_start=1143
  _globals['_REPORTMODELONLINESRESPONSE']._serialized_end=1230
  _globals['_GETPIPELINESREQUEST']._serialized_start=1233
  _globals['_GETPIPELINESREQUEST']._serialized_end=1387
  _globals['_GETPIPELINESRESPONSE']._serialized_start=1389
  _globals['_GETPIPELINESRESPONSE']._serialized_end=1481
  _globals['_GETMODELSREQUEST']._serialized_start=1484
  _globals['_GETMODELSREQUEST']._serialized_end=1635
  _globals['_GETMODELSRESPONSE']._serialized_start=1637
  _globals['_GETMODELSRESPONSE']._serialized_end=1717
  _globals['_GETPIPELINETRIGGERRECORDSREQUEST']._serialized_start=1720
  _globals['_GETPIPELINETRIGGERRECORDSREQUEST']._serialized_end=1955
  _globals['_GETPIPELINETRIGGERRECORDSRESPONSE']._serialized_start=1957
  _globals['_GETPIPELINETRIGGERRECORDSRESPONSE']._serialized_end=2065
  _globals['_GETBULKPIPELINETRIGGERRECORDSREQUEST']._serialized_start=2068
  _globals['_GETBULKPIPELINETRIGGERRECORDSREQUEST']._serialized_end=2201
  _globals['_GETBULKPIPELINETRIGGERRECORDSRESPONSE']._serialized_start=2204
  _globals['_GETBULKPIPELINETRIGGERRECORDSRESPONSE']._serialized_end=2339
  _globals['_GETCUMULATIVEPIPELINETRIGGERRECORDSREQUEST']._serialized_start=2342
  _globals['_GETCUMULATIVEPIPELINETRIGGERRECORDSREQUEST']._serialized_end=2587
  _globals['_GETCUMULATIVEPIPELINETRIGGERRECORDSRESPONSE']._serialized_start=2590
  _globals['_GETCUMULATIVEPIPELINETRIGGERRECORDSRESPONSE']._serialized_end=2729
  _globals['_GETBULKCUMULATIVEPIPELINETRIGGERRECORDSREQUEST']._serialized_start=2732
  _globals['_GETBULKCUMULATIVEPIPELINETRIGGERRECORDSREQUEST']._serialized_end=2885
  _globals['_GETBULKCUMULATIVEPIPELINETRIGGERRECORDSRESPONSE']._serialized_start=2888
  _globals['_GETBULKCUMULATIVEPIPELINETRIGGERRECORDSRESPONSE']._serialized_end=3064
  _globals['_GETPIPELINETRIGGERSUMMARYREQUEST']._serialized_start=3067
  _globals['_GETPIPELINETRIGGERSUMMARYREQUEST']._serialized_end=3302
  _globals['_GETPIPELINETRIGGERSUMMARYRESPONSE']._serialized_start=3304
  _globals['_GETPIPELINETRIGGERSUMMARYRESPONSE']._serialized_end=3409
  _globals['_GETBULKPIPELINETRIGGERSUMMARIESREQUEST']._serialized_start=3412
  _globals['_GETBULKPIPELINETRIGGERSUMMARIESREQUEST']._serialized_end=3547
  _globals['_GETBULKPIPELINETRIGGERSUMMARIESRESPONSE']._serialized_start=3550
  _globals['_GETBULKPIPELINETRIGGERSUMMARIESRESPONSE']._serialized_end=3691
  _globals['_GETMODELONLINERECORDSREQUEST']._serialized_start=3694
  _globals['_GETMODELONLINERECORDSREQUEST']._serialized_end=3916
  _globals['_GETMODELONLINERECORDSRESPONSE']._serialized_start=3918
  _globals['_GETMODELONLINERECORDSRESPONSE']._serialized_end=4019
  _globals['_GETBULKMODELONLINERECORDSREQUEST']._serialized_start=4021
  _globals['_GETBULKMODELONLINERECORDSREQUEST']._serialized_end=4146
  _globals['_GETBULKMODELONLINERECORDSRESPONSE']._serialized_start=4148
  _globals['_GETBULKMODELONLINERECORDSRESPONSE']._serialized_end=4275
  _globals['_GETCUMULATIVEMODELONLINERECORDSREQUEST']._serialized_start=4278
  _globals['_GETCUMULATIVEMODELONLINERECORDSREQUEST']._serialized_end=4510
  _globals['_GETCUMULATIVEMODELONLINERECORDSRESPONSE']._serialized_start=4513
  _globals['_GETCUMULATIVEMODELONLINERECORDSRESPONSE']._serialized_end=4645
  _globals['_GETBULKCUMULATIVEMODELONLINERECORDSREQUEST']._serialized_start=4648
  _globals['_GETBULKCUMULATIVEMODELONLINERECORDSREQUEST']._serialized_end=4793
  _globals['_GETBULKCUMULATIVEMODELONLINERECORDSRESPONSE']._serialized_start=4796
  _globals['_GETBULKCUMULATIVEMODELONLINERECORDSRESPONSE']._serialized_end=4964
  _globals['_GETMODELONLINESUMMARYREQUEST']._serialized_start=4967
  _globals['_GETMODELONLINESUMMARYREQUEST']._serialized_end=5189
  _globals['_GETMODELONLINESUMMARYRESPONSE']._serialized_start=5191
  _globals['_GETMODELONLINESUMMARYRESPONSE']._serialized_end=5288
  _globals['_GETBULKMODELONLINESUMMARYREQUEST']._serialized_start=5290
  _globals['_GETBULKMODELONLINESUMMARYREQUEST']._serialized_end=5415
  _globals['_GETBULKMODELONLINESUMMARYRESPONSE']._serialized_start=5418
  _globals['_GETBULKMODELONLINESUMMARYRESPONSE']._serialized_end=5549
  _globals['_GETPIPELINETRIGGERPRICEREQUEST']._serialized_start=5552
  _globals['_GETPIPELINETRIGGERPRICEREQUEST']._serialized_end=5785
  _globals['_GETPIPELINETRIGGERPRICERESPONSE']._serialized_start=5787
  _globals['_GETPIPELINETRIGGERPRICERESPONSE']._serialized_end=5879
  _globals['_GETBULKPIPELINETRIGGERPRICEREQUEST']._serialized_start=5882
  _globals['_GETBULKPIPELINETRIGGERPRICEREQUEST']._serialized_end=6011
  _globals['_GETBULKPIPELINETRIGGERPRICERESPONSE']._serialized_start=6014
  _globals['_GETBULKPIPELINETRIGGERPRICERESPONSE']._serialized_end=6143
  _globals['_GETMODELONLINEPRICEREQUEST']._serialized_start=6146
  _globals['_GETMODELONLINEPRICEREQUEST']._serialized_end=6366
  _globals['_GETMODELONLINEPRICERESPONSE']._serialized_start=6368
  _globals['_GETMODELONLINEPRICERESPONSE']._serialized_end=6456
  _globals['_GETBULKMODELONLINEPRICEREQUEST']._serialized_start=6458
  _globals['_GETBULKMODELONLINEPRICEREQUEST']._serialized_end=6579
  _globals['_GETBULKMODELONLINEPRICERESPONSE']._serialized_start=6581
  _globals['_GETBULKMODELONLINEPRICERESPONSE']._serialized_end=6702
  _globals['_NULLMESSAGE']._serialized_start=6704
  _globals['_NULLMESSAGE']._serialized_end=6717
  _globals['_USERDATA']._serialized_start=6719
  _globals['_USERDATA']._serialized_end=6779
  _globals['_PIPELINEDATA']._serialized_start=6781
  _globals['_PIPELINEDATA']._serialized_end=6867
  _globals['_PIPELINEUSAGERECORD']._serialized_start=6870
  _globals['_PIPELINEUSAGERECORD']._serialized_end=7163
  _globals['_MODELDATA']._serialized_start=7165
  _globals['_MODELDATA']._serialized_end=7287
  _globals['_MODELUSAGERECORD']._serialized_start=7290
  _globals['_MODELUSAGERECORD']._serialized_end=7470
  _globals['_USAGESUMMARY']._serialized_start=7472
  _globals['_USAGESUMMARY']._serialized_end=7568
  _globals['_PRICEDATA']._serialized_start=7571
  _globals['_PRICEDATA']._serialized_end=7706
  _globals['_TIMEINTERVAL']._serialized_start=7709
  _globals['_TIMEINTERVAL']._serialized_end=7849
# @@protoc_insertion_point(module_scope)
